aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/SkRefDict.h
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /src/core/SkRefDict.h
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'src/core/SkRefDict.h')
-rw-r--r--src/core/SkRefDict.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/core/SkRefDict.h b/src/core/SkRefDict.h
index 55b9bfe0cf..9583df1f12 100644
--- a/src/core/SkRefDict.h
+++ b/src/core/SkRefDict.h
@@ -22,15 +22,15 @@ public:
~SkRefDict();
/**
* Return the data associated with name[], or NULL if no matching entry
* is found. The reference-count of the entry is not affected.
*/
SkRefCnt* find(const char name[]) const;
/**
* If data is NULL, remove (if present) the entry matching name and call
* prev_data->unref() on the data for the matching entry.
* If data is not-NULL, replace the existing entry matching name and
* call (prev_data->unref()), or add a new one. In either case,
* data->ref() is called.
*/
@@ -39,7 +39,7 @@ public:
/**
* Remove the matching entry (if found) and unref its data.
*/
- void remove(const char name[]) { this->set(name, NULL); }
+ void remove(const char name[]) { this->set(name, nullptr); }
/**
* Remove all entries, and unref() their associated data.
@@ -22,15 +22,15 @@ public:
~SkRefDict();
/**
- * Return the data associated with name[], or NULL if no matching entry
+ * Return the data associated with name[], or nullptr if no matching entry
* is found. The reference-count of the entry is not affected.
*/
@@ -22,15 +22,15 @@ public:
SkRefCnt* find(const char name[]) const;
/**
- * If data is NULL, remove (if present) the entry matching name and call
+ * If data is nullptr, remove (if present) the entry matching name and call
* prev_data->unref() on the data for the matching entry.
@@ -22,15 +22,15 @@ public:
* prev_data->unref() on the data for the matching entry.
- * If data is not-NULL, replace the existing entry matching name and
+ * If data is not-nullptr, replace the existing entry matching name and
* call (prev_data->unref()), or add a new one. In either case,
* data->ref() is called.